// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using System.Numerics;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Common;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Layout;
using GrapeCity.Documents.Layout.Composition;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、GrapeCity.Documents.Layout.Composition.Surface クラスと
    // GrapeCity.Documents.Drawing.TableRenderer クラスなどを使用して、
    // 単純な空のテーブルを描画する方法を紹介しています。
    // またこのサンプルでは、TableRenderer クラスを使用して作成できる
    // テーブルレイアウトの主要な要素を確認することができます。
    public class EmptyTable
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;

            DrawTable(g, g.CanvasSize.Width, g.CanvasSize.Height);

            // PDF を保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }

        static readonly TextFormat FormatDesc = new TextFormat()
        {
            Font = GCTEXT.Font.FromFile(Path.Combine("Resources", "Fonts", "ipag.ttc")),
            FontSize = 14,
            FontSizeInGraphicUnits = true,
            ForeColor = Color.White
        };

        static void DrawTable(GcGraphics g, float pageWidth, float pageHeight)
        {
            var surf = new Surface();
            var view = surf.CreateView(pageWidth, pageHeight);

            // ページを灰色で塗りつぶします。
            view.CreateVisual((g, v) => {
                g.FillRectangle(v.AsRectF(), Color.Gray);
            }).LayoutRect.AnchorExact(null);

            var vTable = view.CreateVisual();
            var tableRect = vTable.LayoutRect;
            tableRect.AnchorTopLeftRight(null, 36, 36, 36);

            // paddingAll パラメータは、テーブル矩形を基準にしてテーブルグリッドにパディングを追加します。
            var ta = new TableRenderer(g,
                tableRect, FixedTableSides.TopLeftRight,
                rowCount: 3,
                columnCount: 3,
                gridLineColor: Color.Yellow,
                gridLineWidth: 5,
                rowMinHeight: 100,
                paddingAll: 40);

            var columns = ta.ColumnRects;
            columns[0].SetStarWidth(1);
            columns[1].SetWidth(100);
            columns[2].SetStarWidth(3);

            ta.TableFrameStyle = new FrameStyle
            {
                LinePaddingAll = 20,
                LineColor = Color.SlateBlue,
                FillColor = Color.LightGreen,
                LineWidth = 10f
            };

            ta.ApplyCellConstraints();

            vTable.Draw = (g, v) =>
            {
                var rc = v.AsRectF();
                g.FillRectangle(rc, Color.White);

                var tl = g.CreateTextLayout();
                tl.AppendLine("テーブルの矩形（tableRect）の塗りつぶしの色は白です。", FormatDesc);
                tl.AppendLine("テーブルフレームのパディング（TableFrameStyle.LinePaddingAll）は 20 です。", FormatDesc);
                tl.AppendLine("テーブルフレームの線の幅（TableFrameStyle.LineWidth）は 10 です。", FormatDesc);
                tl.AppendLine("テーブルフレームの線の色（TableFrameStyle.LineColor）は青色です。", FormatDesc);
                tl.AppendLine("テーブルフレームの塗りつぶしの色（TableFrameStyle.FillColor）は黄緑色です。", FormatDesc);
                tl.AppendLine("テーブルグリッドのパディング（paddingAll パラメータ）は 40 です。", FormatDesc);
                tl.AppendLine("テーブルのグリッド線の幅（gridLineWidth パラメータ）は 5 です。", FormatDesc);
                tl.AppendLine("テーブルのグリッド線の色（gridLineColor パラメータ）は黄色です。", FormatDesc);
                g.DrawTextLayout(tl, new PointF(0, rc.Bottom + 10));

                g.Transform = v.Layer.Surface.BaseTransform;
                ta.Render();
            };

            surf.Render(g);
        }
    }
}
